<?php

namespace App\Http\Controllers;

use App\Bank;
use App\Cart;
use App\Order;
use DataTables;
use App\Province;
use App\OrderDetail;
use App\OrderCourier;
use App\AddressShipping;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;

class AddressShippingController extends Controller
{
  public function getShipping()
  {
    $data = AddressShipping::select('address_shipping.*','cities.city_name as kota','provinces.province as provinsi','users.name as nama_user','cities.id as id_kota')
    ->join('cities','address_shipping.id_city','=','cities.id')
    ->join('provinces','address_shipping.id_province','=','provinces.id')
    ->join('users','address_shipping.id_user','=','users.id')
    ->where('address_shipping.status_address_shipping','1')
    ->where('address_shipping.id_user',Auth::guard('web')->user()->id)
    ->get();
    
    return response()->json(['status'=>'SUCCESS','result' => $data]);
  }

  public function courierShipping(Request $request)
  {
    $origin = $request->input('origin');
    $destination = $request->input('destination');
    $berat_produk = $request->input('berat_produk');
    $courier = $request->input('courier');
    if($destination == 'undefined'){
      return response()->json(['message' => 'harap isi alamat pengiriman tujuan']);
    }

    $response = Http::asForm()->withHeaders([
        'key' => '64361250ec1c2b8f6c0a103e7ccb12de'
    ])->post('https://api.rajaongkir.com/starter/cost',[
        'origin' => $origin,
        'destination' => $destination,
        'weight' => $berat_produk,
        'courier' => $courier,
    ]);

    return response()->json(['status'=>'SUCCESS','result' => $response['rajaongkir']['results'][0]]);
  }

  public function detailShipping($id)
  {
    $input_readonly = [];
    if($id==0){
    $data = (Object)[
        'id_address_shipping'=>$id,
        'nama_penerima'=>'',
        'id_province'=>'',
        'id_city'=>'',
        'label_alamat'=>'',
        'detail_alamat'=>'',
        'no_hp'=>'',
        'kode_pos'=>'',
        'status_address_shipping'=>'0'
    ];
    }else{
      $data = AddressShipping::select('address_shipping.*','cities.city_name as kota','provinces.province as provinsi','users.name as nama_user')
      ->join('cities','address_shipping.id_city','=','cities.id')
      ->join('provinces','address_shipping.id_province','=','provinces.id')
      ->join('users','address_shipping.id_user','=','users.id')
      ->where('address_shipping.id_address_shipping',$id)
      ->first();
      if(is_null($data)){
        return response()->json(['error' => 'Data User tidak ada'], 403);
      }
      if($data->status_address_shipping == '2'){
        return response()->json(['error' => 'Data User dihapus'], 403);
      }
    }
    $data->provinces = Province::orderBy('id','asc')->get();
    if($data->status_address_shipping!='0'){
      $input_readonly = ['nama_penerima','id_province','id_city','label_alamat','detail_alamat','no_hp','kode_pos'];
    }
    return view('pages.address_shipping-detail', compact('data','input_readonly'));
  }

  public function saveShipping(Request $request)
  {
    $id = intval($request->input('id_address_shipping'));
    $nama_penerima=$request->input('nama_penerima');
    $no_hp=$request->input('no_hp');
    $kode_pos=$request->input('kode_pos');
    $label_alamat=$request->input('label_alamat');
    $detail_alamat=$request->input('detail_alamat');
    $id_province=$request->input('id_province');
    $id_city=$request->input('id_city');

    $validations = [
      'nama_penerima' => ['Required',Rule::unique('address_shipping','nama_penerima')->where(function($q){
        return $q->where('status_address_shipping','!=','2');
      })->ignore($id,'id_address_shipping')],
      'label_alamat' => 'required',
      'id_province' => 'required',
      'id_city' => ['Required',Rule::unique('address_shipping','id_city')->where(function($q){
        return $q->where('status_address_shipping','!=','2');
      })->ignore($id,'id_address_shipping')],
      'no_hp' => ['Required','numeric',Rule::unique('address_shipping','no_hp')->where(function($q){
        return $q->where('status_address_shipping','!=','2');
      })->ignore($id,'id_address_shipping')],
      'detail_alamat' => 'required',
      'kode_pos' => 'required',
    ];
    $this->validateWith($validations, $request);

    if($id==0){
      $pesan_sukses = 'Data alamat pengiriman berhasil di tambahkan';
      $address_ship = new AddressShipping;
    }else{
      $pesan_sukses = 'Data alamat pengiriman berhasil di ubah';
      $address_ship = AddressShipping::where('id_address_shipping',$id)->first();
      if(is_null($address_ship)){
        return response()->json(['message' => 'Data tidak ada']);
      }
      if($address_ship->status_address_shipping=='2'){
        return response()->json(['message' => 'Data sudah di Hapus']);
      }
    }
    $address_ship->nama_penerima = $nama_penerima;
    $address_ship->id_user = Auth::guard('web')->user()->id;
    $address_ship->label_alamat = $label_alamat;
    $address_ship->no_hp = $no_hp;
    $address_ship->id_province = $id_province;
    $address_ship->id_city = $id_city;
    $address_ship->detail_alamat = $detail_alamat;
    $address_ship->kode_pos = $kode_pos;
    $cek_address = AddressShipping::where('id_user',Auth::guard('web')->user()->id)->get();
    if(count($cek_address) === 0){
      $address_ship->status_address_shipping = '1';
    }else{
      if($address_ship->status_address_shipping == '1'){
        $address_ship->status_address_shipping = '1';
      }else{
        $address_ship->status_address_shipping = '0';
      }
    }
    $address_ship->save();

    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function listShipping()
  {
    $data = AddressShipping::select('address_shipping.*','cities.city_name as kota','provinces.province as provinsi','users.name as nama_user')
      ->join('cities','address_shipping.id_city','=','cities.id')
      ->join('provinces','address_shipping.id_province','=','provinces.id')
      ->join('users','address_shipping.id_user','=','users.id')
      ->where('address_shipping.id_user',Auth::guard('web')->user()->id)
      ->orderBy('address_shipping.status_address_shipping','desc')
      ->get();
    if(count($data) == 0){
      return response()->json(['error' => 'Data alamat tidak ada'], 403);
    }
    return view('pages.address_shipping-list', compact('data'));
  }

  public function getAjaxListShipping()
  {
    $data = AddressShipping::select('address_shipping.*','cities.city_name as kota','provinces.province as provinsi','users.name as nama_user')
      ->join('cities','address_shipping.id_city','=','cities.id')
      ->join('provinces','address_shipping.id_province','=','provinces.id')
      ->join('users','address_shipping.id_user','=','users.id')
      ->where('address_shipping.id_user',Auth::guard('web')->user()->id)
      ->orderBy('address_shipping.status_address_shipping','desc')
      ->get();
      
    return response()->json(['status'=>'SUCCESS','result' => $data]);
  }

  public function firstAddressShipping(Request $request)
  {
    $id = $request->input('id');
    $address_ship = AddressShipping::where('id_address_shipping',$id)->first();
    if(is_null($address_ship)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($address_ship->status_address_shipping=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }
    if($address_ship->status_address_shipping=='1'){
      return response()->json(['message' => 'Data sudah di jadikan utama']);
    }

    AddressShipping::where('id_user',Auth::guard('web')->user()->id)->update(['status_address_shipping'=>'0']);

    $pesan_sukses = 'Data Alamat berhasil di jadikan utama';
    $address_ship->status_address_shipping = '1';
    $address_ship->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function savePayment(Request $request)
  {
    $id_address_shipping = $request->input('id_address_shipping');
    $bank_payment = $request->input('bank_payment');
    $total_produk = $request->input('total_produk');
    $total_tagihan = $request->input('total_tagihan');
    $data_courier=json_decode($request->input('data_courier'),1);
    
    $COURIER_SHIPPING = '';
    
    if($id_address_shipping == 'undefined'){
      return response()->json(['message' => 'Silakan pilih alamat pengiriman tujuan']);
    }

    $validations = [
      'bank_payment' => 'required',
      'data_courier' => [
          function($attribute, $value, $fail) use($data_courier,&$COURIER_SHIPPING){
              $err = [];

              foreach($data_courier as $n => $cour){
                  $err_courier  = [];
                  if($cour['courier']==''){
                      $err_courier[]='courier';
                  }
                  if($cour['courier_cost']==''){
                      $err_courier[]='courier_cost';
                  }
                  if(count($err_courier)>0){
                      $err[] = (Object)[
                          'courier_no'=>$n+1,
                          'input'=>$err_courier
                      ];
                  }

                  $COURIER_SHIPPING.=($COURIER_SHIPPING==''?'':';');
                  $COURIER_SHIPPING.=$cour['courier'].' - '.$cour['courier_cost'];
              }
              if(count($err)>0){
                  $fail(json_encode($err));
              }
          }
      ]
    ];
    $this->validateWith($validations, $request);
    $address_shipping = AddressShipping::where('id_address_shipping',$id_address_shipping)->first();
    $bank = Bank::where('id_bank',$bank_payment)->first();
    $kode_order = $this->generateBukti('order',date('d-m-Y'));
    $order = new Order;
    $order->kode_order = $kode_order;
    $order->tgl_order = date('Y-m-d');
    $order->id_user = Auth::guard('web')->user()->id;
    $order->id_bank = $bank_payment;
    $order->id_address_shipping = $id_address_shipping;
    $order->total_produk_order = 0;
    $order->grand_total_order = $total_tagihan;
    $order->courier = '';
    $order->shipping_cost = '';
    $order->id_toko = 0;
    $order->jenis_payment_order = 'TF';
    $order->bank_payment = $bank->nama_bank;
    $order->id_province = $address_shipping->id_province;
    $order->id_city = $address_shipping->id_city;
    $order->nama_penerima = $address_shipping->nama_penerima;
    $order->label_alamat = $address_shipping->label_alamat;
    $order->detail_alamat = $address_shipping->detail_alamat;
    $order->no_hp = $address_shipping->no_hp;
    $order->save();

    foreach ($data_courier as $it) {
      $order_courier = new OrderCourier;
      $order_courier->courier = $it['courier'];
      $order_courier->id_order = $order->id_order;
      $order_courier->shipping_cost = $it['courier_cost'];
      $order_courier->id_toko = $it['id_toko'];
      $order_courier->save();

      $carts = Cart::select('cart.*','produk.harga_produk')
      ->join('produk','produk.id_produk','=','cart.id_produk')
      ->where('id_user',Auth::guard('web')->user()->id)->where('cart.id_toko',$it['id_toko'])->get();
      foreach ($carts as $cart) {
        $detail_or = new OrderDetail;
        $detail_or->id_order = $order->id_order;
        $detail_or->id_produk = $cart->id_produk;
        $detail_or->harga_produk = $cart->harga_produk;
        $detail_or->qty_produk = $cart->qty;
        $detail_or->sub_total = $cart->harga_produk*$cart->qty;
        $detail_or->id_toko = $it['id_toko'];
        $detail_or->save();
      }
    }
    
    // foreach ($data_courier as $it) {
    //     $order = new Order;
    //     $code_price = mt_rand(000, 999);
    //     $order->kode_order = $kode_order;
    //     $order->id_toko = $it['id_toko'];
    //     $order->tgl_order = date('Y-m-d');
    //     $order->id_user = Auth::guard('web')->user()->id;
    //     $order->id_bank = $bank_payment;
    //     $order->id_address_shipping = $id_address_shipping;
    //     $order->total_produk_order = 0;
    //     $order->grand_total_order = $it['total_harga_produk']+$code_price;
    //     $order->courier = $it['courier'];
    //     $order->shipping_cost = $it['courier_cost'];
    //     $order->jenis_payment_order = 'TF';
    //     $order->bank_payment = $bank->nama_bank;
    //     $order->id_province = $address_shipping->id_province;
    //     $order->id_city = $address_shipping->id_city;
    //     $order->nama_penerima = $address_shipping->nama_penerima;
    //     $order->label_alamat = $address_shipping->label_alamat;
    //     $order->detail_alamat = $address_shipping->detail_alamat;
    //     $order->no_hp = $address_shipping->no_hp;
    //     $order->save();

    //     $carts = Cart::select('cart.*','produk.harga_produk')
    //     ->join('produk','produk.id_produk','=','cart.id_produk')
    //     ->where('id_user',Auth::guard('web')->user()->id)->where('cart.id_toko',$order->id_toko)->get();
    //     foreach ($carts as $cart) {
    //       $detail_or = new OrderDetail;
    //       $detail_or->id_order = $order->id_order;
    //       $detail_or->id_produk = $cart->id_produk;
    //       $detail_or->harga_produk = $cart->harga_produk;
    //       $detail_or->qty_produk = $cart->qty;
    //       $detail_or->sub_total = $cart->harga_produk*$cart->qty;
    //       $detail_or->save();
    //     }
    //   }

      // if($order->kode_order==''){
      //   $order->kode_order = $this->generateBukti('order',date('d-m-Y'));
      //   $order->save();
      // }

      Cart::where('id_user',Auth::guard('web')->user()->id)->delete();
      
      return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">Terima Kasih telah berbelanja di Fish Colors</span>']);
  }
}
