<?php

namespace App\Http\Controllers\Admin;

use Image;
use DataTables;
use App\Artikel;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Http\Controllers\Controller;

class ArtikelController extends Controller
{
    public function index()
    {
      return view('pages.admin.artikel');
    }

    public function getList(Request $request)
		{
			if ($request->ajax()) {
				$data = Artikel::where('status_artikel','<>','2')->orderByDesc('id_artikel')->get();
				return Datatables::of($data)
					->addIndexColumn()
					->addColumn('action', function($data){
            $actionBtn = '<a href="javascript:void(0)" data-id="'.$data->id_artikel.'" class="btn btn-success btn-sm btn-item-edit"><i class="fa fa-edit"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_artikel.'" class="btn btn-danger btn-item-delete btn-sm"><i class="fa fa-trash"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_artikel.'" class="btn btn-primary btn-item-approve btn-sm"><i class="fas fa-lock"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_artikel.'" class="btn btn-primary btn-item-non-approve btn-sm"><i class="fas fa-unlock"></i></a>';
            return $actionBtn;
          })
          ->editColumn('tgl_mulai', function($data) {
            return date('d-m-Y',strtotime($data->tgl_mulai));
          })
          ->editColumn('tgl_akhir', function($data) {
            return date('d-m-Y',strtotime($data->tgl_mulai));
          })
					->rawColumns(['action'])
					->make(true);
			}
		}

    public function detail($id)
		{
			$input_readonly = [];
      if($id==0){
      $data = (Object)[
          'id_artikel'=>$id,
          'judul_artikel'=>'',
          'tgl_mulai'=>date('Y-m-d'),
          'tgl_akhir'=>date('Y-m-d'),
          'isi_artikel'=>'',
          'gambar'=>'',
          'status_artikel'=>'0'
      ];
      }else{
      $data = Artikel::select('*')->where('id_artikel',$id)->first();
        if(is_null($data)){
          return response()->json(['error' => 'Data artikel tidak ada'], 403);
        }
        if($data->status_artikel == '2'){
          return response()->json(['error' => 'Data artikel sudah di hapus'], 403);
        }
      }
      if($data->status_artikel!='0'){
				$input_readonly = ['judul_artikel','tgl_mulai','tgl_akhir','isi_artikel'];
      }
      if($data->status_artikel=='1'){
        if (($key = array_search('judul_artikel', $input_readonly)) !== false) {
          unset($input_readonly[$key]);
        }
        if (($key = array_search('tgl_akhir', $input_readonly)) !== false) {
          unset($input_readonly[$key]);
        }
        if (($key = array_search('tgl_mulai', $input_readonly)) !== false) {
          unset($input_readonly[$key]);
        }
        if (($key = array_search('isi_artikel', $input_readonly)) !== false) {
          unset($input_readonly[$key]);
        }
      }
      return view('pages.admin.artikel-detail', compact('data','input_readonly'));
		}

    public function save(Request $request)
    {
      $id = intval($request->input('id_artikel'));
			$judul_artikel=$request->input('judul_artikel');
			$tgl_mulai=date('Y-m-d',strtotime($request->input('tgl_mulai')));
			$tgl_akhir=date('Y-m-d',strtotime($request->input('tgl_akhir')));
			$isi_artikel=$request->input('isi_artikel');
			$foto_file = $request->file('foto_file');
			$foto_url = $request->input('foto_url');

			$validations = [
				'judul_artikel' => ['Required',Rule::unique('artikel','judul_artikel')->where(function($q){
						return $q->where('status_artikel','!=','2');
				})->ignore($id,'id_artikel')],
        'tgl_mulai' => 'required',
        'tgl_akhir' => 'required',
        'isi_artikel' => 'required',
				];
				if($id==0){
					$validations['foto_file'] = ['required'];
				}
				$this->validateWith($validations, $request);

        //Cek Tanggal Banner
        if($tgl_akhir <= $tgl_mulai){
          return response()->json(['message' => 'Tanggal akhir harus lebih besar dari tanggal mulai']);
        }

				if($id==0){
					$pesan_sukses = 'Data artikel berhasil di tambahkan';
					$artikel = new Artikel;
					}else{
					$pesan_sukses = 'Data artikel berhasil di ubah';
					$artikel = Artikel::where('id_artikel',$id)->first();
					$VALUE_HISTORY = 'Edit';
					if(is_null($artikel)){
						return response()->json(['message' => 'Data tidak ada']);
					}
					if($artikel->status_artikel=='2'){
						return response()->json(['message' => 'Data sudah di Hapus']);
					}
				}

				if(isset($foto_file)){
					$filename_gambar = time().".".$foto_file->getClientOriginalExtension();
					$foto_file->storeAs('public/assets/foto_artikel',$filename_gambar);
					$path_gambar = public_path('storage/assets/foto_artikel/'.$filename_gambar);
					$img_gambar =Image::make($foto_file)->resize(690,287)->save($path_gambar);
					$artikel->gambar = 'assets/foto_artikel/'.$filename_gambar;
				}else{
					$rr=explode('storage/',$foto_url);
					$artikel->gambar=$rr[1];
				}

				$artikel->judul_artikel = $judul_artikel;
				$artikel->slug_artikel = Str::slug($judul_artikel,'-');
				$artikel->tgl_mulai = $tgl_mulai;
				$artikel->tgl_akhir = $tgl_akhir;
				$artikel->tgl_artikel = date('Y-m-d');
				$artikel->isi_artikel = $this->replace_save_images($isi_artikel,'artikel');
				$artikel->save();
				
				return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
    }

    public function del(Request $request)
  {
    $id = intval($request->input('id'));
    $artikel = Artikel::where('id_artikel',$id)->first();
    if(is_null($artikel)){
    return response()->json(['message' => 'Data tidak ada']);
    }
    if($artikel->status_artikel=='2'){
    return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data artikel berhasil di Hapus';
    $artikel->status_artikel = '2';
    $artikel->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function app(Request $request)
  {
    $id = intval($request->input('id'));
    $artikel = Artikel::where('id_artikel',$id)->first();
    if(is_null($artikel)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($artikel->status_artikel=='1'){
      return response()->json(['message' => 'Data sudah Aktif']);
    }
    if($artikel->status_artikel=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data artikel berhasil di Aktifkan:';
    $artikel->status_artikel = '1';
    $artikel->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function nonApp(Request $request)
  {
    $id = intval($request->input('id'));
    $artikel = Artikel::where('id_artikel',$id)->first();
    if(is_null($artikel)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($artikel->status_artikel=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data artikel berhasil di Non Aktifkan';
    $artikel->status_artikel = '0';
    $artikel->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }
}
