<?php

namespace App\Http\Controllers\Admin;

use App\Kategori;
use DataTables;
use Image;
use Illuminate\Validation\Rule;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class KategoriController extends Controller
{
  public function index()
  {
    return view('pages.admin.kategori');
  }

  public function getList(Request $request)
  {
    if ($request->ajax()) {
      $data = Kategori::where('status_kategori','<>','2')->orderByDesc('id_kategori')->get();
      return Datatables::of($data)
        ->addIndexColumn()
        ->addColumn('action', function($data){
          $actionBtn = '<a href="javascript:void(0)" data-id="'.$data->id_kategori.'" class="btn btn-success btn-sm btn-item-edit"><i class="fa fa-edit"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_kategori.'" class="btn btn-danger btn-item-delete btn-sm"><i class="fa fa-trash"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_kategori.'" class="btn btn-primary btn-item-approve btn-sm"><i class="fas fa-lock"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_kategori.'" class="btn btn-primary btn-item-non-approve btn-sm"><i class="fas fa-unlock"></i></a>';
          return $actionBtn;
      })
        ->rawColumns(['action'])
        ->make(true);
    }
  }

  public function detail($id)
  {
    $input_readonly = [];
    if($id==0){
    $data = (Object)[
        'id_kategori'=>$id,
        'nama_kategori'=>'',
        'foto'=>'',
        'status_kategori'=>'0'
    ];
    }else{
    $data = Kategori::select('*')->where('id_kategori',$id)->first();
    if(is_null($data)){
      return response()->json(['error' => 'Data User tidak ada'], 403);
    }
    }
    if($data->status_kategori!='0'){
      $input_readonly = ['nama_kategori'];
    }
    return view('pages.admin.kategori-detail', compact('data','input_readonly'));
  }

  public function save(Request $request)
  {
    $id = intval($request->input('id_kategori'));
    $nama_kategori=$request->input('nama_kategori');
    $foto_file = $request->file('foto_file');
    $foto_url = $request->input('foto_url');

    $validations = [
      'nama_kategori' => ['Required',Rule::unique('kategori','nama_kategori')->where(function($q){
          return $q->where('status_kategori','!=','2');
      })->ignore($id,'id_kategori')],
      ];
      if($id==0){
        $validations['foto_file'] = ['required'];
      }
      $this->validateWith($validations, $request);

      if($id==0){
        $pesan_sukses = 'Data kategori berhasil di tambahkan';
        $kategori = new Kategori;
      }else{
        $pesan_sukses = 'Data kategori berhasil di ubah';
        $kategori = Kategori::where('id_kategori',$id)->first();
        $VALUE_HISTORY = 'Edit';
        if(is_null($kategori)){
          return response()->json(['message' => 'Data tidak ada']);
        }
        // if($kategori->status_kategori=='1'){
        // 	return response()->json(['message' => 'Data sudah Aktif']);
        // }
        if($kategori->status_kategori=='2'){
          return response()->json(['message' => 'Data sudah di Hapus']);
        }
      }

      if(isset($foto_file)){
        $filename_gambar = time().".".$foto_file->getClientOriginalExtension();
        $foto_file->storeAs('public/assets/foto_kategori',$filename_gambar);
        $path_gambar = public_path('storage/assets/foto_kategori/'.$filename_gambar);
        $img_gambar =Image::make($foto_file)->resize(370,270)->save($path_gambar);
        $kategori->foto = 'assets/foto_kategori/'.$filename_gambar;
      }else{
        $rr=explode('storage/',$foto_url);
        $kategori->foto=$rr[1];
      }

      $kategori->nama_kategori = $nama_kategori;
      $kategori->slug_kategori = \Str::slug($nama_kategori);
      $kategori->save();
      
      return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function del(Request $request)
  {
    $id = intval($request->input('id'));
    $kategori = Kategori::where('id_kategori',$id)->first();
    if(is_null($kategori)){
    return response()->json(['message' => 'Data tidak ada']);
    }
    if($kategori->status_kategori=='2'){
    return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data kategori berhasil di Hapus';
    $kategori->status_kategori = '2';
    $kategori->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function app(Request $request)
  {
    $id = intval($request->input('id'));
    $kategori = Kategori::where('id_kategori',$id)->first();
    if(is_null($kategori)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($kategori->status_kategori=='1'){
      return response()->json(['message' => 'Data sudah Aktif']);
    }
    if($kategori->status_kategori=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data kategori berhasil di Aktifkan:';
    $kategori->status_kategori = '1';
    $kategori->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function nonApp(Request $request)
  {
    $id = intval($request->input('id'));
    $kategori = Kategori::where('id_kategori',$id)->first();
    if(is_null($kategori)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($kategori->status_kategori=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data kategori berhasil di Non Aktifkan';
    $kategori->status_kategori = '0';
    $kategori->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

}
