<?php

namespace App\Http\Controllers\Admin;

use App\Order;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use DataTables;
use Image;
use Illuminate\Validation\Rule;

class PesananController extends Controller
{
  public function index()
  {
    return view('pages.admin.pesanan');
  }

  public function getList(Request $request)
  {
    if ($request->ajax()) {
    $data = Order::select('order.*','cities.city_name as kota','cities.postal_code as kode_pos','provinces.province as provinsi','bank_user.*')
    ->leftJoin('bank_user','bank_user.id_bank_user','=','order.id_bank_user')
    ->join('cities','order.id_city','=','cities.id')
    ->join('provinces','order.id_province','=','provinces.id')->get();
      return Datatables::of($data)
        ->addIndexColumn()
        ->addColumn('action', function($data){
          $actionBtn = '<a href="javascript:void(0)" data-id_order="'.$data->id_order.'" class="btn btn-primary btn-sm btn-item-edit"><i class="fa fa-eye"></i></a> '.($data->status_pembayaran=='1'||$data->status_pembayaran=='3'?'':'<a href="javascript:void(0)" data-id="'.$data->id_order.'" class="btn btn-success btn-item-check btn-sm"><i class="fas fa-check"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_order.'" class="btn btn-danger btn-item-non-check btn-sm"><i class="fas fa-times"></i></a>');
          return $actionBtn;
        })
        ->editColumn('info_pesanan', function($data) {
          return '<div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px"><span class="badge bg-primary text-white">'.$data->kode_order.'</span></div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">Tgl Transaksi: '.date('d-m-Y',strtotime($data->tgl_order)).'</div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px"><b style="font-weight:bolder">'.$data->nama_penerima.'</b><span class="badge badge-info p-1">'.$data->label_alamat.'</span></div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">'.$data->no_hp.'</div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">'.$data->detail_alamat.'</div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">'.$data->kota.', '.$data->provinsi.', '.$data->kode_pos.'</div>
                </div>
                ';
        })
        ->editColumn('total_pesanan', function($data) {
          return number_format($data->grand_total_order,0,',','.');
        })
        ->editColumn('status_pesanan', function($data) {
          return '<div>
                    <div>'.($data->status_pembayaran=='0'?(is_null($data->id_bank_user)?'<span class="badge bg-danger text-white">Menunggu Konfirmasi Pembayaran</span>':'<span class="badge bg-warning text-white">Menunggu Pembayaran</span>'):($data->status_pembayaran=='3'?'<span class="badge bg-success text-white">Berhasil di bayar</span><br><span>'.$data->nama_bank.'-'.$data->nama_pemilik_bank.'-'.$data->norek_bank.'</span>':($data->status_pembayaran=='1'?'<span class="badge bg-success text-white">Batal, Melebihi batas waktu</span>':''))).'</div>
                  </div>
                ';
        })
        ->rawColumns(['action','info_pesanan','status_pesanan'])
        ->make(true);
    }
  }

  public function detail(Request $request,$id)
  {

    $order_details = Order::select('order.*','order_detail.*','produk.*','cities.city_name as kota_toko','cities.id as id_kota','toko.*','order_courier.courier as courier_cour','order_courier.shipping_cost as shipping_cost_cour')
    ->join('order_detail','order_detail.id_order','=','order.id_order')
    ->join('order_courier',function($join){
      $join->on('order_courier.id_order','=','order_detail.id_order');
      $join->on('order_courier.id_toko','=','order_detail.id_toko');
      })
    ->join('produk','produk.id_produk','=','order_detail.id_produk')
    ->join('toko','toko.id_toko','=','order_detail.id_toko')
    ->join('cities','toko.id_city','=','cities.id')
    ->where('order_detail.id_order',$id)
    ->groupBy('order_detail.id_produk')
    ->orderBy('order_detail.id_toko','asc')
    ->get();
    $lasttoko='';
      $process = [];
      $produk = null;
      $i = -1;
      $berat=0;
      foreach($order_details as $r){
          if($r->nama_toko !== $lasttoko){
              if($i>-1){
                  $process[$i]['produk']=$produk;
                  $process[$i]['berat']=$berat;
              }
              $i++;
              $produk = [];
              $process[$i]=['nama_toko'=>$r->nama_toko,'kota_toko'=>$r->kota_toko,'id_kota'=>$r->id_kota,'berat'=>0,'id_toko'=>$r->id_toko,'courier_cour_x'=>$r->courier_cour,'shipping_cost_cour_x'=>$r->shipping_cost_cour,'status_order_detail'=>$r->status_order_detail,'status_pembayaran'=>$r->status_pembayaran,'produk'=>[]];
              $lasttoko=$r->nama_toko;
              $berat=0;
          }
          $produk[] = $r;
          $berat+= $r->berat_produk*$r->qty;
      }
      if(count($order_details)>0){
        $process[$i]['produk']=$produk;
        $process[$i]['berat']=$berat;
      }
      // dd($process);
    return view('pages.admin.pesanan-detail', compact('process'));
  }

  public function check(Request $request)
  {
    $id = intval($request->input('id'));
    $order = Order::where('id_order',$id)->first();
    if(is_null($order)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($order->status_pembayaran=='3'){
      return response()->json(['message' => 'Data sudah dibayar']);
    }

    $pesan_sukses = 'Data status order berhasil diubah';
    $order->status_pembayaran = '3';
    $order->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function nonCheck(Request $request)
  {
    $id = intval($request->input('id'));
    $order = Order::where('id_order',$id)->first();
    if(is_null($order)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($order->status_pembayaran=='3'){
      return response()->json(['message' => 'Data sudah dibayar']);
    }

    $pesan_sukses = 'Data status order berhasil diubah';
    $order->status_pembayaran = '1';
    $order->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }
}
