<?php

namespace App\Http\Controllers\Seller;

use Image;
use App\Toko;
use App\Produk;
use DataTables;
use App\Kategori;
use Illuminate\Http\Request;
use Illuminate\Validation\Rule;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Storage;

class ProdukController extends Controller
{
  public function index()
  {
    return view('pages.seller.produk');
  }

  public function getList(Request $request)
  {
    $toko = Toko::where('id_user',Auth::guard('web')->user()->id)->first();
    if ($request->ajax()) {
    $data = Produk::select('produk.*','kategori.nama_kategori')
      ->join('kategori','kategori.id_kategori','=','produk.id_kategori')
      ->where('produk.id_toko','=',$toko->id_toko)
      ->where('produk.status_produk','<>','2')
      ->orderByDesc('id_produk')
      ->get();
    return Datatables::of($data)
      ->addIndexColumn()
      ->addColumn('action', function($data){
        $actionBtn = '<a href="javascript:void(0)" data-id="'.$data->id_produk.'" class="btn btn-success btn-sm btn-item-edit"><i class="fa fa-edit"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_produk.'" class="btn btn-danger btn-item-delete btn-sm"><i class="fa fa-trash"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_produk.'" class="btn btn-primary btn-item-approve btn-sm"><i class="fas fa-lock"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_produk.'" class="btn btn-primary btn-item-non-approve btn-sm"><i class="fas fa-unlock"></i></a>';
        return $data->status_produk=='3'?'<span class="badge bg-danger">Blokir</span>':$actionBtn;
      })
      ->editColumn('info_produk', function($data) {
        return '<div class="d-flex">
                  <img src="/storage/assets/produk/'.$data->foto_1_produk.'" class="img img-thumbnail" style="width:100px">
                  <div style="margin-left:5px">
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px"><b style="font-weight:bolder">'.$data->nama_produk.'</b></div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">'.$data->nama_kategori.'</div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">Min Order:'.$data->min_order_produk.'</div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">Rp'.number_format($data->harga_produk,0,',','.').'</div>
                    <div>'.($data->status_produk=='0'?'<span class="badge bg-danger">Tidak Aktif</span>':($data->status_produk=='1'?'<span class="badge bg-success">Aktif</span>':($data->status_produk=='3'?'<span class="badge bg-danger">Blokir</span>':''))).'</div>
                  </div>
                </div>
                ';
      })
      ->editColumn('stok_produk', function($data) {
        return number_format($data->stok_produk,0,',','.');
      })
      ->rawColumns(['action','info_produk'])
      ->make(true);
    }
  }

  public function detail($id)
  {
    $input_readonly = [];
    if($id==0){
    $data = (Object)[
        'id_produk'=>$id,
        'nama_produk'=>'',
        'id_kategori'=>'',
        'stok_produk'=>'',
        'deskripsi_produk'=>'',
        'min_order_produk'=>'',
        'berat_produk'=>'',
        'satuan_berat_produk'=>'',
        'harga_produk'=>'',
        'pbox_produk'=>'',
        'lbox_produk'=>'',
        'tbox_produk'=>'',
        'foto_1_produk'=>'',
        'foto_2_produk'=>'',
        'foto_3_produk'=>'',
        'foto_4_produk'=>'',
        'status_produk'=>'0'
    ];
    }else{
      $data = Produk::select('produk.*','kategori.nama_kategori')
      ->join('kategori','produk.id_kategori','=','kategori.id_kategori')
      ->where('id_produk',$id)
      ->first();
      if(is_null($data)){
        return response()->json(['error' => 'Data User tidak ada'], 403);
      }
    }
    $data->kategori = Kategori::where('status_kategori','1')->get();
    if($data->status_produk!='0'){
      $input_readonly = ['nama_produk','id_kategori','stok_produk','deskripsi_produk','min_order_produk','berat_produk','satuan_berat_produk','harga_produk','foto_1_produk','foto_2_produk','foto_3_produk','foto_4_produk','pbox_produk','lbox_produk','tbox_produk'];
    }
    return view('pages.seller.produk-detail', compact('data','input_readonly'));
  }

  public function save(Request $request)
  {
    $id = intval($request->input('id_produk'));
    $data = $request->all();
    $nama_produk=$request->input('nama_produk');
    $id_kategori=$request->input('id_kategori');
    $harga_produk=$request->input('harga_produk');
    $stok_produk=$request->input('stok_produk');
    $min_order_produk=$request->input('min_order_produk');
    $berat_produk=$request->input('berat_produk');
    $pbox_produk=$request->input('pbox_produk');
    $lbox_produk=$request->input('lbox_produk');
    $tbox_produk=$request->input('tbox_produk');
    $deskripsi_produk=$request->input('deskripsi_produk');
    $status_produk=$request->input('status_produk');
    $foto_1_file=$request->file('foto_1_file');
    // dd($request);

    $validations = [
      'nama_produk' => 'required',
      'id_kategori' => 'required',
      'harga_produk' => 'required|numeric',
      'stok_produk' => 'required|numeric',
      'min_order_produk' => 'required|numeric|min:1|max:100',
      'berat_produk' => 'required|numeric',
      'deskripsi_produk' => 'required',
    ];
    if($id==0){
      $validations['foto_1_file'] = ['required'];
    }
    $this->validateWith($validations, $request);

    if($id==0){
      $pesan_sukses = 'Data produk berhasil di tambahkan';
      $produk = new Produk;
    }else{
      $pesan_sukses = 'Data produk berhasil di ubah';
      $produk = Produk::where('id_produk',$id)->first();
      if(is_null($produk)){
        return response()->json(['message' => 'Data tidak ada']);
      }
      if($produk->status_produk=='2'){
        return response()->json(['message' => 'Data sudah di Hapus']);
      }
    }
    $toko = Toko::where('id_user',Auth::guard('web')->user()->id)->first();
    if(is_null($toko)){
      return response()->json(['message' => 'Data toko tidak ditemukan']);
    }
    $produk->nama_produk = $nama_produk;
    $produk->slug_produk = \Str::slug($nama_produk);
    $produk->tgl_upload_produk = date('Y-m-d H:i:s');
    $produk->id_toko = $toko->id_toko;
    $produk->id_kategori = $id_kategori;
    $produk->harga_produk = $harga_produk;
    $produk->stok_produk = $stok_produk;
    $produk->min_order_produk = $min_order_produk;
    $produk->berat_produk = $berat_produk;
    $produk->pbox_produk = (is_null($pbox_produk)?0:$pbox_produk);
    $produk->lbox_produk = (is_null($lbox_produk)?0:$lbox_produk);
    $produk->tbox_produk = (is_null($tbox_produk)?0:$tbox_produk);
    $produk->foto_1_produk = '';
    $produk->foto_2_produk = '';
    $produk->foto_3_produk = '';
    $produk->foto_4_produk = '';
    $produk->deskripsi_produk = $deskripsi_produk;
    $produk->status_produk = $status_produk;
    $produk->save();

    foreach (['',1,2,3] as $key => $value) {
      if ($data['foto_'.($key+1).'_hapus'] == '1') {
          $produk->{'foto_'.($key+1).'_produk'} = '';
      }else{
        if(isset($data['foto_'.($key+1).'_file'])){
          $image_file = $request->file('foto_'.($key+1).'_file');
          $filename = $produk->id_produk.'-'.time().rand(000,111).'P.'.$image_file->getClientOriginalExtension();
          $image_file->storeAs('public/assets/produk',$filename);
          $path = public_path('storage/assets/produk/'.$filename);
          $img =Image::make($image_file)->resize(286,250)->save($path);

          $image_file->storeAs('public/assets/produk/thumb',$filename);
          $path = public_path('storage/assets/produk/thumb/'.$filename);
          $img =Image::make($image_file)->resize(70,70)->save($path);

          $image_file->storeAs('public/assets/produk/detail',$filename);
          $path = public_path('storage/assets/produk/detail/'.$filename);
          $img =Image::make($image_file)->resize(470,612)->save($path);

          $produk->{'foto_'.($key+1).'_produk'} = $filename;
        }else{
          $rr=explode('storage/assets/produk/',$data['foto_'.($key+1).'_url']);
          $produk->{'foto_'.($key+1).'_produk'}=$rr[1];
        }
      }
      $produk->save();
    }

    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function del(Request $request)
  {
    $id = intval($request->input('id'));
    $produk = Produk::where('id_produk',$id)->first();
    if(is_null($produk)){
    return response()->json(['message' => 'Data tidak ada']);
    }
    if($produk->status_produk=='2'){
    return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data produk berhasil di Hapus';
    $produk->status_produk = '2';
    $produk->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function app(Request $request)
  {
    $id = intval($request->input('id'));
    $produk = Produk::where('id_produk',$id)->first();
    if(is_null($produk)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($produk->status_produk=='1'){
      return response()->json(['message' => 'Data sudah Aktif']);
    }
    if($produk->status_produk=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data produk berhasil di Aktifkan:';
    $produk->status_produk = '1';
    $produk->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function nonApp(Request $request)
  {
    $id = intval($request->input('id'));
    $produk = Produk::where('id_produk',$id)->first();
    if(is_null($produk)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if($produk->status_produk=='2'){
      return response()->json(['message' => 'Data sudah di Hapus']);
    }

    $pesan_sukses = 'Data produk berhasil di Non Aktifkan';
    $produk->status_produk = '0';
    $produk->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }
}
