<?php

namespace App\Http\Controllers;

use DataTables;
use Image;
use App\Toko;
use App\User;
use App\Order;
use App\BankUser;
use App\OrderDetail;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\Rule;

class SettingController extends Controller
{
  public function index()
  {
    $user = User::where('id',Auth::guard('web')->user()->id)->first();
    return view('pages.setting',compact('user'));
  }
  public function biodataSave(Request $request)
  {
    $user = Auth::guard('web')->user();
    $nama_lengkap=$request->input('nama_lengkap');
    $email=$request->input('email');
    $tempat_lahir=$request->input('tempat_lahir');
    $tgl_lahir=$request->input('tgl_lahir');
    $jenis_kelamin=$request->input('jenis_kelamin');
    $telepon=$request->input('telepon');
    $foto_user_file = $request->file('foto_user_file');
    $foto_user_url = $request->input('foto_user_url');

    $validations=[
      'nama_lengkap' => 'required',
      'tempat_lahir' => 'required',
      'tgl_lahir' => 'required',
      'jenis_kelamin' => 'required',
      'telepon' => 'required',
    ];

    $this->validateWith($validations, $request);
    $data_user = User::where('id',$user->id)->first();
    if(is_null($data_user)){
        return response()->json(['message' => 'Data tidak ada']);
    }
    if($data_user->email !== $email){
      return response()->json(['message' => 'Email tidak boleh diganti']);
    }
    $pesan_sukses = 'Biodata diri berhasil di update';

    if(isset($foto_user_file)){
      $filename_gambar = time().".".$foto_user_file->getClientOriginalExtension();
      $foto_user_file->storeAs('public/assets/user',$filename_gambar);
      $path_gambar = public_path('storage/assets/user/'.$filename_gambar);
      $img_gambar =Image::make($foto_user_file)->resize(250,400)->save($path_gambar);
      $data_user->photo = 'assets/user/'.$filename_gambar;
    }

    $data_user->name = $nama_lengkap;
    $data_user->tempat_lahir = $tempat_lahir;
    $data_user->tgl_lahir = date('Y-m-d',strtotime($tgl_lahir));
    $data_user->jenis_kelamin = $jenis_kelamin;
    $data_user->phone_number = $telepon;
    $data_user->save();

    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function getAjaxListOrder(Request $request)
  {
    $data = Order::select('order.*','cities.city_name as kota','cities.postal_code as kode_pos','provinces.province as provinsi','bank_user.*')
    ->leftJoin('bank_user','bank_user.id_bank_user','=','order.id_bank_user')
    ->join('cities','order.id_city','=','cities.id')
    ->join('provinces','order.id_province','=','provinces.id')
    ->where('order.id_user',Auth::guard('web')->user()->id)
    ->groupBy('order.kode_order')->get();
    return response()->json(['status'=>'SUCCESS','result' => $data]);
  }

  public function getAjaxDetailOrder(Request $request,$id)
  {
    $order = Order::where('id_order',$id)->first();

    $order_details = Order::select('order.*','order_detail.*','produk.*','cities.city_name as kota_toko','cities.id as id_kota','toko.*','order_courier.courier as courier_cour','order_courier.shipping_cost as shipping_cost_cour')
    ->join('order_detail','order_detail.id_order','=','order.id_order')
    ->join('order_courier',function($join){
      $join->on('order_courier.id_order','=','order_detail.id_order');
      $join->on('order_courier.id_toko','=','order_detail.id_toko');
      })
    ->join('produk','produk.id_produk','=','order_detail.id_produk')
    ->join('toko','toko.id_toko','=','order_detail.id_toko')
    ->join('cities','toko.id_city','=','cities.id')
    ->where('order_detail.id_order',$order->id_order)
    ->groupBy('order_detail.id_produk')
    ->orderBy('order_detail.id_toko','asc')
    ->get();
    $lasttoko='';
      $process = [];
      $produk = null;
      $i = -1;
      $berat=0;
      foreach($order_details as $r){
          if($r->nama_toko !== $lasttoko){
              if($i>-1){
                  $process[$i]['produk']=$produk;
                  $process[$i]['berat']=$berat;
              }
              $i++;
              $produk = [];
              $process[$i]=['nama_toko'=>$r->nama_toko,'kota_toko'=>$r->kota_toko,'id_kota'=>$r->id_kota,'berat'=>0,'id_toko'=>$r->id_toko,'id_order'=>$r->id_order,'courier_cour_x'=>$r->courier_cour,'shipping_cost_cour_x'=>$r->shipping_cost_cour,'status_order_detail'=>$r->status_order_detail,'status_pembayaran'=>$r->status_pembayaran,'produk'=>[]];
              $lasttoko=$r->nama_toko;
              $berat=0;
          }
          $produk[] = $r;
          $berat+= $r->berat_produk*$r->qty;
      }
      if(count($order_details)>0){
        $process[$i]['produk']=$produk;
        $process[$i]['berat']=$berat;
      }
      // dd($process);
      return view('pages.setting-detail-order', compact('process'));
  }

  public function saveKonfirmasiPesanan(Request $request)
  {
    $id_order = intval($request->input('id_order'));
    $id_toko = intval($request->input('id_toko'));
    $order_detail = OrderDetail::where('id_order',$id_order)->where('id_toko',$id_toko)->get();
    if(count($order_detail)==0){
      return response()->json(['message' => 'Data tidak ada']);
    }

    $pesan_sukses = 'Transaksi anda sudah selesai';
    OrderDetail::where('id_order',$id_order)->where('id_toko',$id_toko)->update(['status_order_detail'=>'3']);

    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function getAjaxBayarOrder(Request $request,$id){
    $order = Order::select(['order.*','bank.*'])->join('bank','bank.id_bank','=','order.id_bank')->where('id_order',$id)->first();
    $order->list_rekening = BankUser::where('id_user','=',$order->id_user)
    ->where('status_bank','<>','2')
    ->orderByDesc('id_bank_user')
    ->get();
    return view('pages.setting-bayar-order', compact('order'));
  }

  public function saveBayarOrder(Request $request)
  {
    $id = intval($request->input('id_order'));
    $bank = intval($request->input('bank'));

    $validations = [
      'bank' => 'required'
    ];
    $this->validateWith($validations, $request);

    $order = Order::where('id_order',$id)->first();
    $pesan_sukses = 'Data order '.$order->kode_order.' berhasil di simpan';
    if(is_null($order)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    if(is_null($order->status_pembayaran=='3')){
      return response()->json(['message' => 'Data sudah dibayar']);
    }
    $order->id_bank_user = $bank;
    $order->save();
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function getAjaxDetailBayarOrder(Request $request,$id)
  {
    $order = Order::select(['order.*','bank.*'])->join('bank','bank.id_bank','=','order.id_bank')->where('id_order',$id)->first();
    if(is_null($order)){
      return response()->json(['message' => 'Data tidak ada']);
    }
    return view('pages.setting-bayar-order-detail', compact('order'));
  }

  public function getListRekening(Request $request)
  {
    $toko = Toko::where('id_user',Auth::guard('web')->user()->id)->first();
    if ($request->ajax()) {
    $data = BankUser::where('id_user','=',Auth::guard('web')->user()->id)
      ->where('status_bank','<>','2')
      ->orderByDesc('id_bank_user')
      ->get();
    return Datatables::of($data)
      ->addIndexColumn()
      ->addColumn('action', function($data){
        return '<a href="javascript:void(0)" data-id="'.$data->id_bank_user.'" class="btn btn-primary btn-item-edit btn-sm"><i class="fa fa-edit"></i></a> <a href="javascript:void(0)" data-id="'.$data->id_bank_user.'" class="btn btn-danger btn-item-delete btn-sm"><i class="fa fa-trash"></i></a>';
        // return ($data->status_bank=='0'?$actionBtn:'');
      })
      ->editColumn('info_bank', function($data) {
        return '<div>
                  <div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px"><b style="font-weight:bolder">'.$data->nama_bank.'</b></div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">'.$data->nama_pemilik_bank.'</div>
                    <div style="font-size:14px;line-height: 18px;margin-bottom:2px">'.$data->norek_bank.'</div>
                    <div>'.($data->status_bank=='0'?'<a href="javascript:void(0)" data-id="'.$data->id_bank_user.'" class="btn btn-outline-success btn-item-status-utama btn-sm">Jadikan utama</a>':($data->status_bank=='1'?'<span class="badge bg-success">Utama</span>':'')).'</div>
                  </div>
                </div>
                ';
      })
      ->rawColumns(['action','info_bank'])
      ->make(true);
    }
  }

  public function detail($id)
  {
    $input_readonly = [];
    if($id==0){
    $data = (Object)[
        'id_bank_user'=>$id,
        'nama_bank'=>'',
        'nama_pemilik_bank'=>'',
        'norek_bank'=>'',
        'status_bank'=>'0'
      ];
    }else{
      $data = BankUser::where('id_bank_user',$id)->first();
      if(is_null($data)){
        return response()->json(['error' => 'Data bank tidak ada'], 403);
      }
    }
    if($data->status_bank!='0'){
      $input_readonly = ['nama_pemilik_bank','nama_bank','norek_bank'];
    }
    return view('pages.rekening-detail', compact('data','input_readonly'));
  }

  public function saveBankUser(Request $request)
  {
    $toko = Toko::where('id_user',Auth::guard('web')->user()->id)->first();
    $id = intval($request->input('id_bank_user'));
    $nama_pemilik_bank=$request->input('nama_pemilik_bank');
    $nama_bank=$request->input('nama_bank');
    $norek_bank=$request->input('norek_bank');

    $validations = [
      'nama_bank' => ['Required',Rule::unique('bank_user','nama_bank')->where(function($q){
          return $q->where('status_bank','!=','2')->where('id_user',Auth::guard('web')->user()->id);
      })->ignore($id,'id_bank_user')],
      'nama_pemilik_bank' => 'required',
      'norek_bank' => ['Required',Rule::unique('bank_user','norek_bank')->where(function($q){
        return $q->where('status_bank','!=','2');
      })->ignore($id,'id_bank_user')],
      ];
      $this->validateWith($validations, $request);

      $cek_bank = BankUser::where('id_toko',0)->where('id_user',Auth::guard('web')->user()->id)->get();
      if(count($cek_bank)>=2){
        return response()->json(['message' => 'Data bank kamu sudah melebihi batas']);
      }
      
      if($id==0){
        $pesan_sukses = 'Data bank berhasil di tambahkan';
        $bank_user = new BankUser;
      }else{
        $pesan_sukses = 'Data bank berhasil di ubah';
        $bank_user = BankUser::where('id_bank_user',$id)->first();
        if(is_null($bank_user)){
          return response()->json(['message' => 'Data tidak ada']);
        }
        if($bank_user->status_bank=='1'){
          return response()->json(['message' => 'Data sudah Aktif']);
        }
        if($bank_user->status_bank=='2'){
          return response()->json(['message' => 'Data sudah di hapus']);
        }
      }

      $bank_user->nama_pemilik_bank = $nama_pemilik_bank;
      $bank_user->nama_bank = $nama_bank;
      $bank_user->norek_bank = $norek_bank;
      $bank_user->id_toko = 0;
      $bank_user->id_user = Auth::guard('web')->user()->id;
      $bank_user->save();
      return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }

  public function statusUtama(Request $request)
  {
    $id = intval($request->input('id'));
    $bank_user = BankUser::where('id_bank_user',$id)->first();
    if(is_null($bank_user)){
    return response()->json(['message' => 'Data tidak ada']);
    }
    if($bank_user->status_bank=='2'){
    return response()->json(['message' => 'Data sudah di Hapus']);
    }

    // $toko = Toko::where('id_user',Auth::guard('web')->user()->id)->first();
    $cek_bank = BankUser::where('status_bank','1')->where('id_user',Auth::guard('web')->user()->id)->where('id_toko',0)->get();
    if(count($cek_bank)>0){
      BankUser::query()->update(['status_bank' => '0']);
    }

    $pesan_sukses = 'Data bank berhasil di jadikan utama';
    $bank_user->status_bank = '1';
    $bank_user->save();
    
    return response()->json(['status'=>'SUCCESS','message'=>'<span class="text-center">'.$pesan_sukses.'</span>']);
  }
}
